declare type RestFieldSettings = {
    /**
     * Select Value.
     * A function for selecting the value for this rest field.
     * This function is expected to select the value from custom wp/data store related to this field.
     */
    selectValue: () => unknown;
};
/**
 * Defined behavior of a rest field.
 */
declare type RestFields = Record<string, RestFieldSettings>;
/**
 * Register rest fields
 *
 * @param {string} name     Rest field unique name. Must be unique.
 * @param {Object} settings Rest field settings.
 *
 * @example
 * registerRestField('rest-field-example', {
 *    getValue: (select) => select('my-example-store').myExampleSelector();
 * })
 */
export declare const registerRestField: (name: string, settings: RestFieldSettings) => RestFieldSettings | undefined;
/**
 * Returns a registered rest field settings.
 *
 * @param {string} name Rest field name.
 *
 */
export declare function getRestField(name: string): RestFieldSettings;
/**
 * Returns all registered rest fields.
 */
export declare function getRestFields(): RestFields;
export {};
//# sourceMappingURL=index.d.ts.map